@@ -1,7 +1,6 @@
-import os
-
-from affiliate_deeplink.base import BaseDeeplinkGenerator
-from affiliate_deeplink.utils import add_url_params
+from .base import BaseDeeplinkGenerator
+from .config import BW2_AFL_ID
+from .utils import add_url_params
 
 
 class B2w(BaseDeeplinkGenerator):
@@ -14,7 +13,7 @@ class B2w(BaseDeeplinkGenerator):
 
     @classmethod
     def get_tracking_url(cls, url):
-        params = {'franq': os.getenv('BW2_AFL_ID'),
+        params = {'franq': BW2_AFL_ID,
                   'epar': 'b2wafiliados',
                   'hl': 'lower'}
         if 'americanas.com.br' in url:
