@@ -1,7 +1,7 @@
-import os
 from urllib import parse
 
-from affiliate_deeplink.base import BaseDeeplinkGenerator
+from .base import BaseDeeplinkGenerator
+from .config import MGZ_STORE_NAME
 
 
 class Magalu(BaseDeeplinkGenerator):
@@ -13,7 +13,7 @@ class Magalu(BaseDeeplinkGenerator):
     def get_tracking_url(cls, url):
         parsed_uri = parse.urlparse(url)
         splitted_url = parsed_uri.path.split('/')
-        splitted_url[1] = os.getenv('MGZ_STORE_NAME')
+        splitted_url[1] = MGZ_STORE_NAME
         new_path = '/'.join(p for p in splitted_url)
         url = '{scheme}://{netloc}{path}'.format(scheme=parsed_uri.scheme,
                                                  netloc=parsed_uri.netloc,
